# Generated by Django 2.1.2 on 2018-11-20 22:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('provider', '0003_auto_20181114_1350'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='application',
            options={'ordering': ('name',), 'verbose_name': 'Application', 'verbose_name_plural': 'Applications'},
        ),
    ]
